# device-specific setup
{
  pkgs,
  config,
  inputs,
  ...
}: {
  imports = with inputs; [
    chaotic.nixosModules.default
    lix.nixosModules.default
    self.nixosModules.desktop
    self.nixosModules.system
    ./hardware.nix
    ./programs.nix
    ./stylix.nix
    ./disko.nix
    ./users.nix
    ./sops.nix
  ];

  desktop = {
    niri.enable = true;
  };

  nix = {
    channel.enable = false;
    daemonCPUSchedPolicy = "idle";
    settings = {
      experimental-features = ["nix-command" "flakes"];
      builders-use-substitutes = true;
    };
    distributedBuilds = true;
    buildMachines = [
      {
        hostName = "dunamis";
        sshUser = "nix-ssh";
        system = "x86_64-linux";
        sshKey = config.sops.secrets."ssh-eldrid-user".path;
        supportedFeatures = ["nixos-test" "big-parallel" "kvm" "benchmark"];
        publicHostKey = builtins.readFile "${inputs.mysecrets}/ssh/ssh_host_ed25519_dunamis.base64";
      }
    ];
  };

  system.stateVersion = "25.05";

  time.timeZone = "Europe/Kyiv";
  locale.ukrainian.enable = true;

  networking = {
    networkmanager.enable = true;
    hostName = "eldrid";
    hosts = {
      "192.168.1.42" = ["dunamis"];
    };
  };

  boot = {
    # kernelPackages = pkgs.linuxPackages_latest;
    kernelPackages = pkgs.linuxPackages_cachyos;
    plymouth.enable = true;
    loader.efi.canTouchEfiVariables = true;
    loader.systemd-boot = {
      enable = true;
      consoleMode = "auto";
    };
  };

  console = {
    earlySetup = true;
    packages = [pkgs.terminus_font];
    font = "${pkgs.terminus_font}/share/consolefonts/ter-c18n.psf.gz";
  };

  services = {
    power-profiles-daemon.enable = true;
    flatpak.enable = true;
    fstrim.enable = true;
    openssh.enable = true;
    syncthing.openDefaultPorts = true;
    dnscrypt-proxy2 = {
      enable = true;
      settings = {
        require_dnssec = true;
        server_names = ["mullvad-doh"];
        bootstrap_resolvers = ["9.9.9.11:53" "9.9.9.9:53"];
      };
    };
  };
  services.scx = {
    enable = true;
    scheduler = "scx_flash";
  };

  security.basic.enable = true;

  virtual = {
    libvirt.enable = true;
    podman.enable = false;
  };

  wireless.bluetooth.enableBlueman = true;

  opentabletdriver.enable = false;
  qmk-vial.enable = true;
}
